// Imports
#import "ImageInfoApp.h"

// Start of implementation
@implementation ImageInfoApp

	// Show the help for the command
	+(void)showHelp {
		printf( "command help\n" );
	}

	// Show the EXIF information
	+(void)showExifInfo:(NSString*)path {

		// Get the complete path
		NSString *completePath = [path stringByStandardizingPath];
		
		// Convert it to an url
		NSURL *url = [NSURL fileURLWithPath:completePath];
		CGImageRef imageRef = NULL;
		CGImageSourceRef sourceRef;

		// Get the image handle
		sourceRef = CGImageSourceCreateWithURL((CFURLRef)url, NULL);
		if (sourceRef) {
		
			// Open the image
			imageRef = CGImageSourceCreateImageAtIndex(sourceRef, 0, NULL);
			
			// Show the image properties
			NSDictionary* props = (NSDictionary*) CGImageSourceCopyPropertiesAtIndex(sourceRef, 0, NULL);
			printf("\nImage Data for %s: %s\n", [completePath cString], [[props description] cString]);
			
			// Clean up
			[props release];
			CFRelease(sourceRef);
			
		}

	}

	// List the volumes
	+(void)listVolumes {
	
		// Access the shared workspace
		NSWorkspace* workspace = [NSWorkspace sharedWorkspace];
	
		// Get the list of volumes
		NSArray* volumes = [workspace mountedLocalVolumePaths];
		
		// Get the number of items
		unsigned count = [volumes count];
		
		// Loop over the arguments
		int i;
		for ( i = 0; i < count; i++ ) {
		
			// Get the filename from the arguments
			NSString* volume = [volumes objectAtIndex:i];
			
			// Show the Volume name
			printf( "\nVolume: %s", [volume cString] );
			
		}
	
	}

	// Run a command
	+(NSString*)runCommand:(NSString*)cmd {
	
		// Create an empty string
		NSMutableString* mutableString = [NSMutableString stringWithCapacity:0];

		// Create a thread pool
		NSAutoreleasePool *threadPool = [[NSAutoreleasePool alloc] init];

		// Create a new task
	    NSTask *task = [[NSTask alloc] init];

		// Configure the task
		[task setStandardOutput: [NSPipe pipe]];
		[task setStandardError: [task standardOutput]];
		[task setLaunchPath:cmd];

		// Launch the task
		[task launch];
		
		// Append the output
		NSData *data;
		while ((data = [[[task standardOutput] fileHandleForReading] availableData]) && [data length]) {
			NSString* output = [[[NSString alloc] initWithData:data encoding:NSASCIIStringEncoding] autorelease];
			[mutableString appendString:output];
		}
		
		// Make sure the task is finished
		[task terminate];
	
		// Release the thread pool
		[threadPool release];

		// Return the output
		return mutableString;

	}

@end
